# No post-install actions are required.  Code models (*.cm) and the OSDI
# headers are loaded at run time from /usr/lib*/ngspice and
# /usr/share/ngspice; spinit points at them with absolute paths.
:
